@@ -2,6 +2,18 @@ from dataclasses import dataclass, field
 
 import requests
 
+DEFAULT_CONFIG = {
+    'tts': False,
+    'stripSSML': True,
+    'stopAll': True,
+    'stopTypes': [],
+    'excludeTypes': [
+        'block',
+        'debug',
+        'flow',
+    ]
+}
+
 
 @dataclass
 class Interact:
@@ -15,7 +27,7 @@ class Interact:
             'Authorization': self.api_key,
         }
 
-    def interact_request(self, body: dict):
+    def interact_request(self, body: dict) -> dict:
         response = requests.post(
             f'{self.api_base_url}/state/user/{self.user_id}/interact',
             json=body,
@@ -23,21 +35,25 @@ class Interact:
         )
         return response.json()
 
-    def launch(self):
+    def launch(self, config: dict = None) -> dict:
         body = {
             'action': {
                 'type': 'launch',
-            }
+            },
+            'config': config or DEFAULT_CONFIG,
         }
         response = self.interact_request(body=body)
         return response
 
-    def text(self, user_input: str):
+    def text(self,
+             user_input: str,
+             config: dict = None) -> dict:
         body = {
             'action': {
                 'type': 'text',
                 'payload': user_input,
-            }
+            },
+            'config': config or DEFAULT_CONFIG,
         }
         response = self.interact_request(body=body)
         return response
